pub struct Flag(pub Arc<RwLock<bool>>);Expand description
Structure that consists of a bool wrapped in Arc and RwLock to ensure thread safety and protect against race conditions.
Since the RwLock used is from the tokio, it can be used asynchronously.
Important: Before passing the flag to a new thread clone it.
Tuple Fields
0: Arc<RwLock<bool>>Implementations
Sourceimpl Flag
impl Flag